function bar(props__2) {}
var Foo = function Foo1__3() {
    _classCallCheck(this, Foo1__3);
    super();
    _defineProperty(this, 'onBar', ()=>{
        bar();
    });
    bar();
};
